@@ -175,6 +175,7 @@ public class CDFCompare extends JFrame
     String cdfspec2 = " ";
     String filespec = "";
     String cdfDelimiter1, cdfDelimiter2;
+    String[] cmds = new String[3];
 
 /** A platform-dependent Runtime object. */
     Runtime runtime = Runtime.getRuntime();
@@ -542,10 +543,19 @@ public class CDFCompare extends JFrame
 	} else if (obj == helpb || obj == menuHelpHelp) { // for "Help" 
 		commandX = command + "-java";
                 hlp = 1;
-                // runit(cmds);
-                runit(commandX);
+                String OS = System.getProperty("os.name").toLowerCase();
+                if (OS.indexOf("windows") != -1) {
+                    cmds[0] = commandX;
+                } else if (OS.indexOf("vms") != -1) {
+                    cmds[0] = commandX;
+                } else {
+                    cmds[0] = "/bin/sh";
+                    cmds[1] = "-c";
+                    cmds[2] = commandX;
+                }
+                runit(cmds);
+                // runit(commandX);
 		hlp = 0;
-
             // try {
             // Process proc = runtime.exec(commandX);
             // put a BufferedReader on the ls output
@@ -605,22 +615,33 @@ public class CDFCompare extends JFrame
                     	  Caches = "-cache " + caches.substring(1,caches.length()-2) + " ";
                      else Caches = "-cache " + caches + " ";
 
-                // if (cdfspec1.startsWith("'")) cdfDelimiter1 = " ";
-                // else if (cdfspec1.startsWith("\"")) cdfDelimiter1 = " ";
-                // else cdfDelimiter1 = "'";
-                // if (cdfspec2.startsWith("'")) cdfDelimiter2 = " ";
-                // else if (cdfspec2.startsWith("\"")) cdfDelimiter2 = " ";
-                // else cdfDelimiter2 = "'";
+                if (cdfspec1.startsWith("'")) cdfDelimiter1 = " ";
+                else if (cdfspec1.startsWith("\"")) cdfDelimiter1 = " ";
+                else cdfDelimiter1 = "\"";
+                if (cdfspec2.startsWith("'")) cdfDelimiter2 = " ";
+                else if (cdfspec2.startsWith("\"")) cdfDelimiter2 = " ";
+                else cdfDelimiter2 = "\"";
 
 		commandX = command + strpo + strca + strcv + strcn +
                            strce   + strlp + strzz + strdl + strds +
                            strdp   + strdv + report + zmodes + 
-			   Caches  + " " + cdfspec1 + " " + cdfspec2;
-			   // Caches  + cdfDelimiter1 + cdfspec1 + 
-			   // cdfDelimiter1+ " " + cdfDelimiter2 + 
-			   // cdfspec2 + cdfDelimiter2;
-		// runit(cmds);
-		runit(commandX);
+			   // Caches  + " " + cdfspec1 + " " + cdfspec2;
+			   Caches  + cdfDelimiter1 + cdfspec1 + 
+			   cdfDelimiter1+ " " + cdfDelimiter2 + 
+			   cdfspec2 + cdfDelimiter2;
+                String OS = System.getProperty("os.name").toLowerCase();
+                if (OS.indexOf("windows") != -1) {
+                    cmds[0] = commandX;
+                } else if (OS.indexOf("vms") != -1) {
+                    commandX = commandX.replace('-', '/');
+                    cmds[0] = commandX;
+                } else {
+                    cmds[0] = "/bin/sh";
+                    cmds[1] = "-c";
+                    cmds[2] = commandX;
+                }
+		runit(cmds);
+		// runit(commandX);
 	} else if (obj == cdf1) {
 		cdfspec1 = cdf1.getText();
 	} else if (obj == cdf2) {
@@ -802,8 +823,18 @@ public class CDFCompare extends JFrame
                 if (abc.isSelected()) {
 		  abcX = 1;
                   commandX = command + " -about";
-                  // runit(cmds);
-                  runit(commandX);
+                  String OS = System.getProperty("os.name").toLowerCase();
+                  if (OS.indexOf("windows") != -1) {
+                      cmds[0] = commandX;
+                  } else if (OS.indexOf("vms") != -1) {
+                      cmds[0] = commandX;
+                  } else {
+                      cmds[0] = "/bin/sh";
+                      cmds[1] = "-c";
+                      cmds[2] = commandX;
+                  }
+                  runit(cmds);
+                  // runit(commandX);
                   abc.setSelected(false);
 		  abcX = 0;
                 }
@@ -887,12 +918,14 @@ public class CDFCompare extends JFrame
     the results in the text area.
  */
 
-    // private void runit(String[] command) {
-    private void runit(String command) {
+    private void runit(String[] command) {
+    // private void runit(String command) {
         try {
-		// if (System.getProperty("os.name").equalsIgnoreCase("VMS"))
-		//   command[2] = command[2].replace('-', '/');
-                process = runtime.exec(command);
+                if (command[1] != null)
+                  process = runtime.exec(command);
+                else
+                  process = runtime.exec(command[0]);
+/*
                 if (iba == 1 && hlp == 0 && abcX == 0) {
                    info.setText("Program is submitted...\n\n");
                    info.append("Compared results will be created in: " + 
@@ -902,6 +935,7 @@ public class CDFCompare extends JFrame
                     info.setText("");
                     info.append("Program is running...\n");
                   }
+*/
                   Dimension dialogSize = dialog.getSize();
                   ((JComponent)(dialog.getContentPane())).paintImmediately(
                                                 0, 0, dialogSize.width, dialogSize.height);
@@ -910,8 +944,8 @@ public class CDFCompare extends JFrame
                                   InputStreamReader(process.getInputStream()), 8192);
 		  boolean first = true;
                   String line = null;
-		  if (hlp == 1 || abcX == 1 || ricX == 1 || rwcX == 1 || recX == 1 ||
-                      lpcX == 1 || dscX == 1 || dlcX == 1 || dpcX == 1 || dvcX == 1) {
+//		  if (hlp == 1 || abcX == 1 || ricX == 1 || rwcX == 1 || recX == 1 ||
+//                      lpcX == 1 || dscX == 1 || dlcX == 1 || dpcX == 1 || dvcX == 1) {
                     while ((line = inStream.readLine()) != null) {
 		      if (first) {
 			info.setText("");
@@ -919,11 +953,13 @@ public class CDFCompare extends JFrame
 		      }
                       info.append(line+"\n");
 		    }
-		  }
+//		  }
                   process.waitFor();
 		  info.setCaretPosition(0);
-                  if (process.exitValue() == 1) Toolkit.getDefaultToolkit().beep();
-		}
+                  if (process.exitValue() == 1) {
+		    Toolkit.getDefaultToolkit().beep();
+		    info.append("ERROR: error is detected... job failed\n");
+		  } 
         } catch (Exception e) {
                 info.setText("error executing: "+e);
                 Toolkit.getDefaultToolkit().beep();
