@@ -68,6 +68,8 @@ public class CDFDir extends JFrame
     Runtime runtime = Runtime.getRuntime();
 /** A separate process to run the command. */
     Process process = null;
+    
+    String[] cmds = new String[3];
 
 /** The text field is currently getting the focus. */
     JTextField focused = null;
@@ -304,14 +306,26 @@ public class CDFDir extends JFrame
 		} 
                 else {
                     cdfspec = cdfspec.trim();
+                    String cdfDelimiter;
+                    if (cdfspec.startsWith("'")) cdfDelimiter = " ";
+                    else if (cdfspec.startsWith("\"")) cdfDelimiter = " ";
+                    else cdfDelimiter = "\"";
+
                     String OS = System.getProperty("os.name").toLowerCase();
-                    if (OS.indexOf("windows") != -1)
-                        commandX = "cmd /c dir " + cdfspec + ".*";
-                    else if (OS.indexOf("vms") != -1)
-                        commandX = "spawn dir " + cdfspec + ".*";
-                    else
-		        commandX = command + cdfspec;
-                    runit(commandX);
+                    if (OS.indexOf("windows") != -1) {
+                        cmds[0] = "cmd /c dir " + cdfDelimiter + cdfspec + cdfDelimiter;
+                    } else if (OS.indexOf("vms") != -1) {
+                        cdfspec = cdfspec.replace('-', '/');
+                        commandX = "spawn dir " + cdfDelimiter + cdfspec + cdfDelimiter;
+                        cmds[0] = commandX;
+                    } else {
+		        commandX = "ls -l " + cdfDelimiter + cdfspec + cdfDelimiter;
+		        cmds[0] = "/bin/sh";
+		        cmds[1] = "-c";
+		        cmds[2] = commandX;
+                    }
+                    runit(cmds);
+		    // runit(commandX);
 		}
 	} else if (obj == cdf) {
 		cdfspec = cdf.getText();
@@ -431,15 +445,14 @@ public class CDFDir extends JFrame
     the results in the text area.
  */
 
-    // private void runit(String[] command) {
-    private void runit(String command) {
+    private void runit(String[] command) {
+    // private void runit(String command) {
 	try {
-           if (System.getProperty("os.name").toLowerCase().indexOf("vms") != -1)
-              command = command.replace('-', '/');
+              if (command[1] != null)
+                process = runtime.exec(command);
+              else
+                process = runtime.exec(command[0]);
 
-	      // if (System.getProperty("os.name").equalsIgnoreCase("VMS"))
-	      //    command[2] = command[2].replace('-', '/');
-              process = runtime.exec(command);
               BufferedReader inStream = new BufferedReader(new
                                 InputStreamReader(process.getInputStream()), 8192);
               String line = null;
@@ -487,17 +500,6 @@ public class CDFDir extends JFrame
            if (selectedFile != null) {
               int ind;
               String myfile = selectedFile.getAbsolutePath();
-              if (theone == 1) { // for .cdf file
-                  ind = myfile.lastIndexOf(".cdf");
-                  if (ind != -1) myfile = myfile.substring(0, ind);
-                  ind = myfile.lastIndexOf(".CDF");
-                  if (ind != -1) myfile = myfile.substring(0, ind);
-              } else { // for .skt file
-                  ind = myfile.lastIndexOf(".skt");
-                  if (ind != -1) myfile = myfile.substring(0, ind);
-                  ind = myfile.lastIndexOf(".SKT");
-                  if (ind != -1) myfile = myfile.substring(0, ind);
-              }
 	      fileChooser.setCurrentDirectory(selectedFile);
               textField.setText(myfile);
            }
