@@ -35,12 +35,8 @@ public class CDFIRsDump extends JFrame
 
 /** "Page Output" check box. */
     JCheckBox pgc = new JCheckBox("Page Output", false);
-/** "Check Sizes" check box. */
-    JCheckBox csc = new JCheckBox("Check Sizes");
 /** "Show Summary" check box. */
     JCheckBox ssc = new JCheckBox("Show Summary");
-/** "Show Indexing" check box. */
-    JCheckBox sic = new JCheckBox("Show Indexing");
 /** "About" check box. */
     JCheckBox abc = new JCheckBox("About");
     int abcX = 0;
@@ -289,10 +285,8 @@ public class CDFIRsDump extends JFrame
         dumpPanel.add(dump2);
 
 //	makeJButton(panel2, pgc, 0, 0, 1, 1, 0.0, 0.0);
-        makeJButton(panel2, csc, 0, 0, 1, 1, 0.0, 0.0);
-        makeJButton(panel2, ssc, 1, 0, 1, 1, 0.0, 0.0);
-        makeJButton(panel2, sic, 0, 1, 1, 1, 0.0, 0.0);
-	makeJButton(panel2, abc, 1, 1, 1, 1, 0.0, 0.0);
+        makeJButton(panel2, ssc, 0, 0, 1, 1, 0.0, 0.0);
+	makeJButton(panel2, abc, 1, 0, 1, 1, 0.0, 0.0);
 //        makeJButton(panel2, bac, 1, 1, 1, 1, 0.0, 0.0);
         tpanel1.add(DUMP,BorderLayout.WEST);
         tpanel1.add(dumpPanel, BorderLayout.CENTER);
@@ -303,12 +297,8 @@ public class CDFIRsDump extends JFrame
 
 	pgc.addItemListener(this);
         pgc.setToolTipText("Select to display the output one page at a time -- not avaiable for Java");
-        csc.addItemListener(this);
-        csc.setToolTipText("Select to dump all internal data record sizes");
         ssc.addItemListener(this);
         ssc.setToolTipText("Select to dump only summary information");
-        sic.addItemListener(this);
-        sic.setToolTipText("Select to dump all inernal indexing records information");
 	abc.addItemListener(this);
         abc.setToolTipText("Display the current version");
 	bac.addItemListener(this);
@@ -548,21 +538,11 @@ public class CDFIRsDump extends JFrame
                 abc.setSelected(false);
 		abcX = 0;
 	   }
-        } else if (obj == csc) { // "Check Sizes" checkbox
-           if (csc.isSelected())
-                strcs = "-sizes ";
-           else
-                strcs = "-nosizes ";
         } else if (obj == ssc) { // "Show Summary" checkbox
            if (ssc.isSelected())
                 strss = "-summary ";
            else
                 strss = "-nosummary ";
-	} else if (obj == sic) { // "Show Indexing" checkbox
-           if (sic.isSelected())
-                strsi = "-indexing ";
-           else
-                strsi = "-noindexing ";
 	} else if (obj == bac) { // "Run it Batch" checkbox
 	   if (bac.isSelected()) {
 		iba = 1;
