@@ -19,11 +19,11 @@ public class ReadCDF implements CDFConstants{
         try {
             CDF cdf = null; 
             if (args.length == 0) {
-                cdf  = CDF.open(fileName, READONLYoff);
+                cdf  = CDF.open(fileName, READONLYon);
             }
             else {
                 fileName = args[0];
-                cdf = CDF.open(fileName, READONLYoff);
+                cdf = CDF.open(fileName, READONLYon);
             }
 
 	    if (cdf.getStatus() != CDF_OK)
